@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "theme-anchor" "0.1.0"
+(define-package "theme-anchor" "20250620.13"
   "Apply theme in current buffer only."
   '((emacs "26"))
   :url "https://github.com/GongYiLiao/theme-anchor"
